@@ -62,6 +62,31 @@ class MergeKVDescriptor:
         self.value_indexs: List[List[int]] = []
 
 
+class DataLine:
+    """
+    数据行
+    """
+    def __init__(self, line_idx, data:List):
+        self.__line_idx = line_idx
+        self.__data = data
+
+    @property
+    def line_idx(self):
+        """
+        原原始数据中的行索引
+        :return:
+        """
+        return self.__line_idx
+
+    @property
+    def data(self):
+        """
+        数据行
+        :return:
+        """
+        return self.__data
+
+
 class DefaultParsedData(BaseParsedData):
     """
     分析后的数据，应用本身不处理此数据，由后续插件处理，因此也可以用其它的数据格式表示分析后的数据
@@ -76,7 +101,8 @@ class DefaultParsedData(BaseParsedData):
         self.key_descriptors: List[bool or str] = []
         self.field_names: List[str] = []
         self.field_comments: List[str] = []
-        self.field_values: List[List[str]] = []
+        # 数据行
+        self.field_values: List[DataLine] = []
         # 唯一键列表（索引)
         self.unique_keys: List[int] = []
         # 合并键映射，以合并tag为键
