@@ -26,7 +26,7 @@ class SaveConfigSignal(Signal):
 
 
 @singleton
-class SaveConfigFinishSignal(Signal):
+class SaveConfigFinishedSignal(Signal):
     """
     保存配置完成时的信号
     """
@@ -34,6 +34,18 @@ class SaveConfigFinishSignal(Signal):
         super().dispatch(config)
 
 
+@singleton
+class RemoveConfigSignal(Signal):
+    def dispatch(self, config_name: str):
+        super().dispatch(config_name)
+
+
+@singleton
+class RemoveConfigFinishedSignal(Signal):
+    def dispatch(self, config_name: str):
+        super().dispatch(config_name)
+
+
 @singleton
 class UpdateConfigsSignal(Signal):
     """
@@ -87,7 +99,7 @@ class RequestToInstallPluginSignal(Signal):
 
 
 @singleton
-class InstallPluginFinishSignal(Signal):
+class InstallPluginFinishedSignal(Signal):
     def dispatch(self, plugin: IPlugin):
         super().dispatch()
 
